@@ -30,7 +30,7 @@ extern "C"
 #endif
 #endif
 
-#define STRINGPREP_VERSION "0.0.0"
+#define STRINGPREP_VERSION "0.0.1"
 
 /* Error codes */
 enum {
@@ -95,6 +95,11 @@ extern long *stringprep_utf8_to_ucs4_fast (const char *str,
 					   int  len, int *items_written);
 extern char *stringprep_ucs4_to_utf8 (const long * str, int len, 
 				      int * items_read, int * items_written);
+extern const char *stringprep_locale_charset ();
+extern char *stringprep_convert (const char *str,
+				 const char *to_codeset,
+				 const char *from_codeset);
+extern char *stringprep_locale_to_utf8 (const char  *opsysstring);
 
 #ifdef __cplusplus
 }
